#<div align="center">
    <h1 align="center">TradingView Types</h1>
    <p align="center">Pydantic models for handling TradingView data.</p>
    <p>
        <img src="https://img.shields.io/badge/python-3.10+-blue.svg" alt="Python version">
        <img src="https://img.shields.io/badge/license-MIT-green.svg" alt="License">
        <img src="https://img.shields.io/pypi/dm/pv_types?style=flat-square" />
        <img src="https://img.shields.io/badge/PRs-welcome-brightgreen.svg" alt="PRs welcome">
    </p>
</div>

# Overview

This package contains auto-generated pydantic dataclasses for TradingView.

Autogenerated with datamodel-code-generator.